function commonSubmitArgs = getCommonSubmitArgs(cluster, numWorkers)
% Get any additional submit arguments for the Slurm sbatch command
% that are common to both independent and communicating jobs.

% Copyright 2016-2019 The MathWorks, Inc.

% https://www.lido.tu-dortmund.de/cms/de/LiDO3/LiDO3_first_contact_handout.pdf

commonSubmitArgs = '';

% Number of cores/node
ppn = validatedPropValue(cluster, 'ProcsPerNode', 'double');
if ppn>0
    % Don't request more cores/node than workers
    ppn = min(numWorkers,ppn);
    commonSubmitArgs = sprintf('%s --ntasks-per-node=%d',commonSubmitArgs,ppn);
end
commonSubmitArgs = sprintf('%s --ntasks-per-core=1',commonSubmitArgs);


%% REQUIRED

% Physical Memory used by a single core
mu = validatedPropValue(cluster, 'MemUsage', 'char');
if isempty(mu)
    emsg = sprintf(['\n\t>> %% Must set MemUsage.  E.g.\n\n', ...
                    '\t>> c = parcluster;\n', ...
                    '\t>> c.AdditionalProperties.MemUsage = ''4gb'';\n', ...
                    '\t>> c.saveProfile\n\n']);
    error(emsg)
else
    commonSubmitArgs = [commonSubmitArgs ' --mem-per-cpu=' mu];
end


%% OPTIONAL

% Constraint
cstr = validatedPropValue(cluster, 'Constraint', 'char');
if ~isempty(cstr)
    commonSubmitArgs = [commonSubmitArgs ' --constraint ' cstr];
end

% Partition / Queue Name
qn = validatedPropValue(cluster, 'QueueName', 'char');
if ~isempty(qn)
    commonSubmitArgs = [commonSubmitArgs ' -p ' qn];
end

% GPUs
ngpus = validatedPropValue(cluster, 'GpusPerNode', 'double');
if ngpus>0
    commonSubmitArgs = sprintf('%s --gres=gpu:%d', commonSubmitArgs, ngpus);
end

% Walltime
wt = validatedPropValue(cluster, 'WallTime', 'char');
if ~isempty(wt)
    commonSubmitArgs = [commonSubmitArgs ' -t ' wt];
end

% Require Exclusive Node
ren = validatedPropValue(cluster, 'RequireExclusiveNode', 'logical');
if ren
    commonSubmitArgs = [commonSubmitArgs ' --exclusive'];
end

% Email notification
ea = validatedPropValue(cluster, 'EmailAddress', 'char');
if ~isempty(ea)
    commonSubmitArgs = [commonSubmitArgs ' --mail-type=ALL --mail-user=' ea];
end

% Catch-all
asa = validatedPropValue(cluster, 'AdditionalSubmitArgs', 'char');
if ~isempty(asa)
    commonSubmitArgs = [commonSubmitArgs ' ' asa];
end

commonSubmitArgs = strtrim(commonSubmitArgs);
